@@ -1,6 +1,8 @@
 use crate::build::{ConstType, ConstVal, ShadowConst};
 use crate::ci::CiType;
 use crate::err::*;
+use crate::time::BuildTime;
+use crate::Format;
 use chrono::SecondsFormat;
 use std::collections::HashMap;
 use std::io::{BufReader, Read};
@@ -75,7 +77,7 @@ impl Git {
         #[cfg(feature = "git2")]
         {
             use crate::git::git2_mod::git_repo;
-            use chrono::{DateTime, Local, NaiveDateTime, Utc};
+            use chrono::{DateTime, NaiveDateTime, Utc};
 
             let repo = git_repo(path).map_err(ShadowError::new)?;
             let reference = repo.head().map_err(ShadowError::new)?;
@@ -107,12 +109,8 @@ impl Git {
 
             let time_stamp = commit.time().seconds().to_string().parse::<i64>()?;
             let dt = NaiveDateTime::from_timestamp(time_stamp, 0);
-            let date_time = DateTime::<Utc>::from_utc(dt, Utc);
-            let date_time: DateTime<Local> = DateTime::from(date_time);
-            self.update_str(
-                COMMIT_DATE,
-                date_time.format("%Y-%m-%d %H:%M:%S").to_string(),
-            );
+            let date_time = BuildTime::Utc(DateTime::<Utc>::from_utc(dt, Utc));
+            self.update_str(COMMIT_DATE, date_time.human_format());
 
             self.update_str(COMMIT_DATE_2822, date_time.to_rfc2822());
 
