@@ -33,7 +33,7 @@
 //! pub const BUILD_TIME :&str = "2020-08-16 13:48:52";
 //! pub const BUILD_TIME_2822 :&str = "Thu, 24 Jun 2021 21:44:14 +0800";
 //! pub const BUILD_TIME_3339 :&str = "2021-06-24T15:53:55+08:00";
-//! pub const COMMIT_DATE :&str = "2020-08-16 13:12:52";
+//! pub const COMMIT_DATE :&str = "2021-08-04 12:34:03 +00:00";
 //! pub const COMMIT_DATE_2822 :&str = "Thu, 24 Jun 2021 21:44:14 +0800";
 //! pub const COMMIT_DATE_3339 :&str = "2021-06-24T21:44:14.473058+08:00";
 //! pub const COMMIT_EMAIL :&str = "xxx@gmail.com";
@@ -111,7 +111,7 @@
 //!    println!("{}",build::BRANCH); //master
 //!    println!("{}",build::SHORT_COMMIT);//8405e28e
 //!    println!("{}",build::COMMIT_HASH);//8405e28e64080a09525a6cf1b07c22fcaf71a5c5
-//!    println!("{}",build::COMMIT_DATE);//2020-08-16T06:22:24+00:00
+//!    println!("{}",build::COMMIT_DATE);//2021-08-04 12:34:03 +00:00
 //!    println!("{}",build::COMMIT_AUTHOR);//baoyachi
 //!    println!("{}",build::COMMIT_EMAIL);//xxx@gmail.com
 //!
@@ -144,6 +144,7 @@ mod ci;
 mod env;
 mod err;
 mod git;
+mod time;
 
 use build::*;
 use env::*;
@@ -151,6 +152,7 @@ use env::*;
 use git::*;
 
 use crate::ci::CiType;
+use crate::time::BuildTime;
 use std::collections::HashMap;
 use std::env as std_env;
 use std::fs::File;
@@ -166,6 +168,10 @@ use chrono::Local;
 pub use err::{SdResult, ShadowError};
 pub use git::{branch, tag};
 
+trait Format {
+    fn human_format(&self) -> String;
+}
+
 const SHADOW_RS: &str = "shadow.rs";
 
 /// Add a mod in project with `$build_mod`.
@@ -349,7 +355,7 @@ impl Shadow {
 /// Author by:https://www.github.com/baoyachi
 /// The build script repository:https://github.com/baoyachi/shadow-rs
 /// Create time by:{}"#,
-            Local::now().format("%Y-%m-%d %H:%M:%S").to_string()
+            BuildTime::Local(Local::now()).human_format()
         );
         writeln!(&self.f, "{}\n\n", desc)?;
         Ok(())
